%define anolis_release 1
%global meson_python_flags  -Dwith_py3=true
%global build_python3 1

%global meson_accept_overflowed_buildorder_flag -Daccept_overflowed_buildorder=true

%global upstream_name libmodulemd

Name:           %{upstream_name}
Version:        2.15.0
Release:        %{anolis_release}%{?dist}
Summary:        Module metadata manipulation library

# COPYING:      MIT
## not in any binary package
# contrib/coverity-modeling.c:  GPLv2+
# contrib/release-tools/semver: GPLv3
License:        MIT
URL:            https://github.com/fedora-modularity/libmodulemd
Source0:        %{url}/releases/download/%{version}/modulemd-%{version}.tar.xz

BuildRequires:  gnupg2
BuildRequires:  meson >= 0.47
BuildRequires:  pkgconfig
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(yaml-0.1)
BuildRequires:  pkgconfig(gtk-doc)
BuildRequires:  glib2-doc
BuildRequires:  rpm-devel
BuildRequires:  file-devel
%if %{build_python3}
BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  python%{python3_pkgversion}-gobject-base
%endif


%description
C library for manipulating module metadata files.
See https://github.com/fedora-modularity/libmodulemd/blob/master/README.md for
more details.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%if %{build_python3}
%package -n python%{python3_pkgversion}-%{name}
Summary:        Python 3 bindings for %{name}
Requires:       %{name} = %{version}-%{release}
Requires:       python%{python3_pkgversion}-gobject-base
Requires:       %{py3_dist six}

%description -n python%{python3_pkgversion}-%{name}
Python %{python3_pkgversion} bindings for %{name}.
%endif


%package devel
Summary:        Development files for libmodulemd
Requires:       %{name} = %{version}-%{release}

%description devel
Development files for %{name}.


%prep
%autosetup -p1 -n modulemd-%{version}


%build
%meson \
    %{meson_accept_overflowed_buildorder_flag} \
    -Dlibmagic=enabled \
    -Drpmio=enabled \
    -Dskip_introspection=false \
    -Dtest_installed_lib=false \
    -Dwith_docs=true \
    -Dwith_manpages=enabled \
    %{meson_python_flags}
%meson_build


%check
export LC_CTYPE=C.utf8
# The tests sometimes time out in CI, so give them a little extra time
%{__meson} test -C %{_vpath_builddir} %{?_smp_mesonflags} --print-errorlogs -t 5


%install
%meson_install

%ldconfig_scriptlets


%files
%license COPYING
%{_bindir}/modulemd-validator%{?v2_suffix}
%{_mandir}/man1/modulemd-validator%{?v2_suffix}.1*
%{_libdir}/%{upstream_name}.so.2*
%dir %{_libdir}/girepository-1.0
%{_libdir}/girepository-1.0/Modulemd-2.0.typelib

%files doc
%doc NEWS README.md

%files devel
%{_libdir}/%{upstream_name}.so
%{_libdir}/pkgconfig/modulemd-2.0.pc
%{_includedir}/modulemd-2.0/
%dir %{_datadir}/gir-1.0
%{_datadir}/gir-1.0/Modulemd-2.0.gir
%dir %{_datadir}/gtk-doc
%dir %{_datadir}/gtk-doc/html
%{_datadir}/gtk-doc/html/modulemd-2.0/


%if %{build_python3}
%files -n python%{python3_pkgversion}-%{name}
%{python3_sitearch}/gi/overrides/
%endif


%changelog
* Mon Mar 25 2024 mgb01105731 <mgb01105731@alibaba-inc.com> - 2.15.0-1
- update to 2.15.0

* Tue Mar 12 2024 Bo Ren <rb01097748@alibaba-inc.com> - 2.14.0-3
- Rebuild with python3.11

* Fri Sep 30 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 2.14-2
- add doc package

* Wed Mar 09 2022 pangqing <pangqing@uniontech.com> - 2.14-1
- Init for anolisOS 23


